Returns functions m and m_inv which apply tubal transforms defined by the Discrete Cosine Transform (DCT-II variant). This is equivalent to Scipys DCTI-ii algorithm with norm='ortho'.

dctii_m_transforms(t, bpparam = NULL)

Arguments

t

The length of the transform.

bpparam

A BiocParallelParam-class object indicating the type of parallelisation.

Value

m

A function which applies the dct-ii along the last dimension of a given numerical input array. For 3D tensors it performs the mode-3 product with the DCT matrix.

minv

The inverse of m,

Author

Brendan Lu