This function works cumulatively across any arbitrary number of tensor inputs.

m_product(..., m = NULL, minv = NULL, bpparam = NULL)

Arguments

...

Arbitrary number of numerical tensor inputs.

m

A function which applies an orthogonal tensor tubal transform.

minv

The inverse of m.

bpparam

A BiocParallelParam-class object indicating the type of parallelisation. Does not have any effect if transform functions explicitly set using m, minv.

Value

Cumulative m-product.

Author

Brendan Lu