Returns functions m and m_inv which apply tubal transforms defined by the matrix m_mat.

matrix_to_m_transforms(m_mat, m_inv_mat = NULL, bpparam = NULL)

Arguments

m_mat

Matrix which defines the tubal transform.

m_inv_mat

Matrix which defines inverse tubal transform

bpparam

A BiocParallelParam-class object indicating the type of parallelisation.

Value

m

A function which applies the matrix m_mat along the last dimension of a given numerical input array. For 3D tensors it performs the mode-3 product.

minv

The inverse of m.

Author

Brendan Lu