m_product.RdThis function works cumulatively across any arbitrary number of tensor inputs.
m_product(..., m = NULL, minv = NULL, bpparam = NULL)Arbitrary number of numerical tensor inputs.
A function which applies an orthogonal tensor tubal transform.
The inverse of m.
A BiocParallelParam-class object
indicating the type of parallelisation. Does not have any effect if transform
functions explicitly set using m, minv.
Cumulative m-product.