tsvdm.RdReturn the t-SVDM decomposition from Kilmer et al. (2021).
tsvdm(
x,
m = NULL,
minv = NULL,
transform = TRUE,
keep_hats = FALSE,
svals_matrix_form = FALSE,
bpparam = NULL
)Tensor input.
A function which applies an orthogonal tensor tubal transform.
The inverse of m.
Set to FALSE if the input is already in a m-transformed space, and you just want a facewise svd returned (this is used in tpls).
Set to TRUE if you do not want minv to be applied to the output (this is used in tpca), i.e. return outputs in the hat-space.
Setting to TRUE will return a compressed version of the singular values tensor S, where the singular values of each f-diagonal frontal slice becomes the column of a matrix, with t columns in total.
A BiocParallelParam-class object
indicating the type of parallelisation. Does not have any effect if transform
functions explicitly set using m, minv.
A list containing:
Left m-product unitary tensor. If keep_hats = TRUE, the tensor
is returned in the m-transform space without the inverse transform
applied at the end, in this case, this return item is called uhat.
Singular values as a tensor with f-diagonal structure, or a
compressed matrix of singular values of each tensor faceas columns when
svals_matrix_form = TRUE (named shat when keep_hats = TRUE).
Right m-product unitary tensor. If keep_hats = TRUE, the tensor
is returned in the m-transform space without the inverse transform
applied at the end, in this case, this return item is called vhat.